@@ -47,6 +47,20 @@ __extern int tolower(int);
 
 extern const unsigned char __ctypes[];
 
+__must_inline int __ctype_isalnum(int);
+__must_inline int __ctype_isalpha(int);
+__must_inline int __ctype_isascii(int);
+__must_inline int __ctype_isblank(int);
+__must_inline int __ctype_iscntrl(int);
+__must_inline int __ctype_isdigit(int);
+__must_inline int __ctype_isgraph(int);
+__must_inline int __ctype_islower(int);
+__must_inline int __ctype_isprint(int);
+__must_inline int __ctype_ispunct(int);
+__must_inline int __ctype_isspace(int);
+__must_inline int __ctype_isupper(int);
+__must_inline int __ctype_isxdigit(int);
+
 __must_inline int __ctype_isalnum(int __c)
 {
 	return __ctypes[__c + 1] &
@@ -118,6 +132,9 @@ __must_inline int __ctype_isxdigit(int __c)
 #define _toupper(__c) ((__c) & ~32)
 #define _tolower(__c) ((__c) | 32)
 
+__must_inline int __ctype_toupper(int);
+__must_inline int __ctype_tolower(int);
+
 __must_inline int __ctype_toupper(int __c)
 {
 	return __ctype_islower(__c) ? _toupper(__c) : __c;
@@ -133,7 +150,7 @@ __must_inline int __ctype_tolower(int __c)
   __extern int X(int);
 #else
 #define __CTYPEFUNC(X) \
-  __extern inline int X(int __c)		\
+  __extern_inline int X(int __c)		\
   {						\
     return __ctype_##X(__c); 			\
   }
